yakumo.keystone.v2.project

Package yakumo :: Package keystone :: Package v2 :: Module project |
[hide private]
[frames] | no frames]

# Module project

source code

Resource class and its manager for projects in Identity V2 API

Classes | [hide private]
| Resource resource class for projects on Identity V2 API
| Manager manager class for projects on Identity V2 API

Variables | [hide private]
| ATTRIBUTE_MAPPING = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass obj`...``
| __package__ = ``'``yakumo.keystone.v2``'``

Variables Details | [hide private]

  ### ATTRIBUTE_MAPPING Value:
      [('id', 'id', mapper.Noop), ('name', 'name', mapper.Noop), ('descripti
      on', 'description', mapper.Noop), ('is_enabled', 'enabled', mapper.Noo
      p),]